"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calcProjects = void 0;
// eslint-disable-next-line @typescript-eslint/no-var-requires
const { getUsedObjectIDs } = require('../www/js/visUtils');
/**
 * Calculate the number of data points for each project of given instance
 *
 * @param options - database and project information
 */
async function calcProject(options) {
    const { visAdapter, instance, objects, projects } = options;
    const result = [];
    if (!(projects === null || projects === void 0 ? void 0 : projects.length)) {
        return result;
    }
    for (const project of projects) {
        if (!(project === null || project === void 0 ? void 0 : project.isDir)) {
            continue;
        }
        if (!(await objects.fileExists(`${visAdapter}.${instance}`, `/${project.file}/vis-views.json`))) {
            continue;
        }
        // calculate data points in one project
        const data = await objects.readFile(`${visAdapter}.${instance}`, `/${project.file}/vis-views.json`);
        let json;
        try {
            json = JSON.parse(data.file);
        }
        catch {
            console.error(`Cannot parse "/${project.file}/vis-views.json`);
            continue;
        }
        const dps = getUsedObjectIDs(json, false);
        if (dps === null || dps === void 0 ? void 0 : dps.IDs) {
            result.push({
                id: `${visAdapter}.${instance}.datapoints.${project.file.replace(/[.\\s]/g, '_')}`,
                val: dps.IDs.length
            });
        }
    }
    return result;
}
/**
 * Calculate the number of data points for all vis projects of given instance
 *
 * @param options - db and vis options
 */
async function calcProjects(options) {
    const { visAdapter, instance, objects } = options;
    const projects = await objects.readDirAsync(`${visAdapter}.${instance}`, '/');
    if (!(projects === null || projects === void 0 ? void 0 : projects.length)) {
        return [{ id: `${visAdapter}.${instance}.datapoints.total`, val: 0 }];
    }
    const result = await calcProject({ objects, projects, instance, visAdapter });
    if (result === null || result === void 0 ? void 0 : result.length) {
        let total = 0;
        for (const entry of result) {
            total += entry.val;
        }
        result.push({ id: `${visAdapter}.${instance}.datapoints.total`, val: total });
    }
    return result;
}
exports.calcProjects = calcProjects;
//# sourceMappingURL=states.js.map